SyndicationTool - Policies: Manage the policies of a Site's Syndication Instance
================================================================================

Description
-----------

View and manage the prolicies of a sitewide syndication instance.

Controls
--------

  **Allow-Override** --
  Each of the properties configureable from the Properties management form
  will have an override switch on the policies management form. This is
  currently unavailable and will be incorporated into the 1.1 release of the
  SyndicationTool.
